%define debug_package %{nil}

Summary:	Internet traffic decoder and network forensic analysis tool

Packager:	Lawrence R. Rogers (lrr@cert.org)

Vendor:		cert.org
Name:		xplico
Version:	1.2.0
Release:	3%{?dist}
URL:		http://www.xplico.org/

License:	GPL

Group:		Applications/Forensics Tools
Source0:	%{name}-%{version}.tar.gz
Patch1:		%{name}-%{version}-patch-001
Patch2:		%{name}-%{version}-patch-002
Patch3:		%{name}-%{version}-patch-003
Patch4:		%{name}-%{version}-patch-004

BuildRoot:	%{buildroot}
BuildRequires:	GeoIP-devel
BuildRequires:	mysql-devel
BuildRequires:	sqlite-devel
BuildRequires:	libpcap-devel
BuildRequires:	nDPI-devel
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	libtool
BuildRequires:	gettext
%if 0%{?centos} >= 6
BuildRequires:	postgresql-devel postgresql
%else
BuildRequires:	postgresql-devel
%endif
BuildRequires:	json-c-devel
Requires:	GeoIP
Requires:	mysql
Requires:	sqlite
Requires:	libpcap
Requires:	wireshark
Requires:	httpd
Requires:	php-pdo
Requires:	php
Requires:	recode
Requires:	sox
Requires:	lame
BuildRequires:	lame-devel
Requires:	videosnarf
Requires:	ghostpdl
Requires:	python3-httplib2
Requires:	nDPI
%if 0%{?fedora} || 0%{?centos} >= 7
Requires:	python3-psycopg2
%endif
%if 0%{?fedora} >= 18
BuildRequires:	python3 >= 3.3
Requires:	python3 >= 3.3
%endif
%if 0%{?fedora} >= 15 && 0%{?fedora} <= 17
Requires:	python3 >= 3.2, python3 < 3.3
BuildRequires:	python3 >= 3.2, python3 < 3.3
%endif
%if 0%{?centos} == 5 || 0%{?centos} == 6
Requires:	python3 >= 3.1, python3 < 3.2
BuildRequires:	python3 >= 3.1, python3 < 3.2
%endif
%if 0%{?centos} == 7
Requires:	python3 >= 3.3
BuildRequires:	python3 >= 3.3
%endif

%description
The goal of Xplico is extract from an internet traffic capture the
applications data contained.  For example, from a pcap file Xplico
extracts each email (POP, IMAP, and SMTP protocols), all HTTP contents,
each VoIP call (SIP), FTP, TFTP, and so on. Xplico isn’t a network
protocol analyzer. Xplico is an open source Network Forensic Analysis Tool
(NFAT).

%prep
%setup  -q
%patch1 -p1
%if 0%{?centos} >= 6
%patch2 -p1
%endif
%if 0%{?centos} == 6
%patch3 -p1
%endif
%patch4 -p1

find . -type f -name '*.orig' -exec rm '{}' \;

################################################################################
# Get the GeoLite database
################################################################################
wget http://geolite.maxmind.com/download/geoip/database/GeoLiteCity.dat.gz
if [ -f GeoLiteCity.dat.gz ]; then gunzip GeoLiteCity.dat.gz; fi

%build
%if 0%{?fedora} >= 22
env CC="gcc -std=gnu89" %{__make}
%else
%{__make}
%endif

%install
make install DESTDIR=$RPM_BUILD_ROOT
################################################################################
# Add the script to manage the service and add the configuration file for the
# local web server.
################################################################################
%if 0%{?fedora} >= 17 || 0%{?centos} >= 7
%__install -Dp init.d/%{name} %{buildroot}%{_sbindir}/%{name}
mkdir -p %{buildroot}/usr/lib/systemd/system
cat > %{buildroot}/usr/lib/systemd/system/%{name}.service <<EOF
[Unit]
Description=The Xplico Open Source Network Forensics Analysis Tool
After=httpd.service

[Service]
Type=notify
Environment=LANG=C
Type=forking

ExecStart=%{_sbindir}/%name start
ExecReload=%{_sbindir}/%name restart
ExecStop=%{_sbindir}/%name stop

[Install]
WantedBy=multi-user.target
EOF
%else
%__install -Dp init.d/%{name} %{buildroot}/etc/init.d/%{name}
%endif
%__install -Dp httpd/%{name}.conf %{buildroot}/etc/httpd/conf.d/%{name}.conf
%if 0%{?centos} == 6
sed --in-place -e '/Require all granted/d' -e '/open_basedir/s/tmp/tmp:\/var/' %{buildroot}/etc/httpd/conf.d/%{name}.conf
%endif
################################################################################
# Remove the database from the distribution. This is now handled conditionally
# when the package is installed.
################################################################################
rm -f %{buildroot}/opt/xplico/xplico.db

################################################################################
# Remove the apache2 stuff - we replace it with something else
################################################################################
rm -rf %{buildroot}/etc/apache2

%if 0%{?centos} == 6
rm -rf %{buildroot}/usr/lib/systemd/system
%endif

%clean
%{__rm} -rf %{buildroot}

%post

%if 0%{?centos} == 6
/sbin/chkconfig --del xplico
/sbin/chkconfig --add xplico
%else
/usr/bin/systemctl disable xplico.service
/usr/bin/systemctl enable  xplico.service
%endif
XPLICO_BASE=/opt/xplico
DB=$XPLICO_BASE/xplico.db
DB_OLD=$XPLICO_BASE/xplico_old.db
DB_NEW=$XPLICO_BASE/xplico_new.db
XI=$XPLICO_BASE/xi/app/
XPLICO_SQLITE_BASE=$XPLICO_BASE/script/db/sqlite

cd $XPLICO_SQLITE_BASE
if [ -e "$DB" ]; then
	echo "Preserving previous Xplico database"
%if 0%{?centos} == 6
	service xplico status | grep -q running
%else
	/usr/bin/systemctl status xplico.service 
%endif
	XPLICO_SERVER_STATUS=$?
	if [ "$XPLICO_SERVER_STATUS" -eq 0 ]; then
%if 0%{?centos} == 6
		service xplico stop
%else
		/usr/bin/systemctl stop xplico.service
%endif
	fi
	mv $DB $DB_OLD
	sh create_xplico_db.sh
	mv $DB $DB_NEW
	mv $DB_OLD $DB
	sh create_xplico_db.sh
	python3 upgrade_db.py
	rm -f $DB_NEW
	rm -rf /opt/xplico/xi/app/tmp/cache/models/*
	rm -rf /opt/xplico/xi/app/tmp/cache/views/*
	if [ "$XPLICO_SERVER_STATUS" -eq 0 ]; then
%if 0%{?centos} == 6
		service xplico start
%else
		/usr/bin/systemctl start xplico.service
%endif
	fi
else
	echo "Creating new Xplico database"
	sh create_xplico_db.sh
fi
chown apache.apache $DB
if [ -f /usr/bin/pcl6 ]; then
	cp -p /usr/bin/pcl6 /opt/xplico/bin
fi
if [ -f /usr/bin/videosnarf ]; then
	cp -p /usr/bin/videosnarf /opt/xplico/bin
fi

%preun
if [ $1 = 0 ]; then
%if 0%{?centos} == 6
	/sbin/service xplico stop > /dev/null 2>&1
	/sbin/chkconfig --del xplico
%else
	/usr/bin/systemctl stop xplico.service
	/usr/bin/systemctl disable xplico.service
%endif
fi
if [ -f /opt/xplico/bin/pcl6 ]; then
	rm -f /opt/xplico/bin/pcl6
fi
if [ -f /opt/xplico/bin/videosnarf ]; then
	rm -f /opt/xplico/bin/videosnarf
fi

%files
%doc AUTHORS ChangeLog COPYING.CC_BY-NC-SA INSTALL LICENSE COPYING.GPLv2.0 DEPENDENCES README
%defattr(0644, apache, apache, 0755)
%attr(755, apache, apache)	/etc/httpd/conf.d/xplico.conf
%attr(644, root, root)	 	/etc/httpd/conf/extra/httpd-xplico.conf
%if 0%{?fedora} >= 17 ||0%{?centos} == 7
%attr(755, root, root)		%{_sbindir}/xplico
%endif
%if 0%{?centos} == 6
%attr(755, root, root)		/etc/init.d/xplico
%else
%attr(644, root, root)		/usr/lib/systemd/system/%{name}.service
%endif
%dir				/opt/xplico/log
%dir				/opt/xplico/cfg
%attr(644, apache, apache)	/opt/xplico/cfg/sol_subdir.cfg
%attr(644, apache, apache)	/opt/xplico/cfg/dema_my.cfg
%attr(644, apache, apache)	/opt/xplico/cfg/mfbc_install_lite.cfg
%attr(644, apache, apache)	/opt/xplico/cfg/mpaltalk_cli.cfg
%attr(644, apache, apache)	/opt/xplico/cfg/dema.cfg
%attr(644, apache, apache)	/opt/xplico/cfg/mfbc_cli.cfg
%attr(644, apache, apache)	/opt/xplico/cfg/mwebymsg_install_lite.cfg
%attr(644, apache, apache)	/opt/xplico/cfg/mwmail_install_lite.cfg
%attr(644, apache, apache)	/opt/xplico/cfg/xplico_install_lite.cfg
%attr(644, apache, apache)	/opt/xplico/cfg/httpd_xi
%attr(644, apache, apache)	/opt/xplico/cfg/mpaltalk_install_lite.cfg
%attr(644, apache, apache)	/opt/xplico/cfg/apache_xi
%attr(644, apache, apache)	/opt/xplico/cfg/mwmail_cli.cfg
%attr(644, apache, apache)	/opt/xplico/cfg/webymsg_cli.cfg
%attr(644, apache, apache)	/opt/xplico/cfg/xplico_cli.cfg
%attr(644, apache, apache)	/opt/xplico/cfg/tcp_grb_dig.cfg
%attr(644, apache, apache)	/opt/xplico/cfg/dema_pg.cfg
%attr(644, apache, apache)	/opt/xplico/cfg/xplico_cli_nc.cfg
%attr(644, apache, apache)	/opt/xplico/cfg/xplico_install_mysql.cfg
%attr(644, apache, apache)	/opt/xplico/cfg/mfile_cli.cfg
%attr(644, apache, apache)	/opt/xplico/cfg/mfile_install_lite.cfg
%attr(644, apache, apache)	/opt/xplico/COPYING.GPLv2.0
%attr(644, apache, apache)	/opt/xplico/LICENSE
%dir				/opt/xplico/script
%attr(755, apache, apache)	/opt/xplico/script/session_mng.pyo
%attr(755, apache, apache)	/opt/xplico/script/sqlite_demo.sh
%attr(755, apache, apache)	/opt/xplico/script/xml2pcap.php
%attr(644, apache, apache)	/opt/xplico/script/sqlite_users.pyo
%dir				/opt/xplico/script/db
%dir				/opt/xplico/script/db/sqlite
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/mmscontents.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/upgrade_db.pyc
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/nntp_articles.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/pjls.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/whatsapps.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/tftps.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/feeds.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/msns.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/syslogs.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/ftps.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/upgrade_db.pyo
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/clean.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/httpfiles.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/telnets.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/webmail.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/arps.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/inputs.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/mms.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/pols.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/sources.sql
%attr(755, apache, apache)	/opt/xplico/script/db/sqlite/upgrade_db.py
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/nntp_groups.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/webs.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/sips.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/params.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/fbuchats.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/paltalk_exps.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/fbchats.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/unkfiles.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/icmpv6s.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/rtps.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/tftp_files.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/ftp_files.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/webymsgs.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/mgcps.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/default.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/emails.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/users.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/groups.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/unknows.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/irc_channels.sql
%attr(755, apache, apache)	/opt/xplico/script/db/sqlite/create_xplico_db.sh
%attr(755, apache, apache)	/opt/xplico/script/db/sqlite/clean_xplico_db.sh
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/sols.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/ircs.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/feed_xmls.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/dns_messages.sql
%attr(644, apache, apache)	/opt/xplico/script/db/sqlite/paltalks.sql
%dir				/opt/xplico/script/db/mysql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/mmscontents.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/nntp_articles.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/pjls.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/whatsapps.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/tftps.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/feeds.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/msns.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/syslogs.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/ftps.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/clean.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/httpfiles.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/telnets.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/webmail.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/arps.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/inputs.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/mms.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/pols.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/sources.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/nntp_groups.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/webs.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/sips.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/params.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/fbuchats.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/paltalk_exps.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/fbchats.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/unkfiles.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/icmpv6s.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/rtps.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/tftp_files.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/ftp_files.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/webymsgs.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/mgcps.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/default.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/emails.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/users.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/groups.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/unknows.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/irc_channels.sql
%attr(755, apache, apache)	/opt/xplico/script/db/mysql/create_xplico_db.sh
%attr(755, apache, apache)	/opt/xplico/script/db/mysql/clean_xplico_db.sh
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/sols.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/ircs.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/feed_xmls.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/dns_messages.sql
%attr(644, apache, apache)	/opt/xplico/script/db/mysql/paltalks.sql
%attr(755, apache, apache)	/opt/xplico/script/mimedump.py
%attr(755, apache, apache)	/opt/xplico/script/mimedump.pyc
%attr(644, apache, apache)	/opt/xplico/script/sqlite_users.pyc
%attr(755, apache, apache)	/opt/xplico/script/session_mng.py
%attr(755, apache, apache)	/opt/xplico/script/mimedump.pyo
%attr(755, apache, apache)	/opt/xplico/script/sqlite_users.py
%attr(755, apache, apache)	/opt/xplico/script/session_mng.pyc
%attr(755, apache, apache)	/opt/xplico/script/xplico
%dir				/opt/xplico/bin
%attr(755, apache, apache)	/opt/xplico/bin/wbm_rediff.pyc
%attr(755, apache, apache)	/opt/xplico/bin/mfile
%attr(755, apache, apache)	/opt/xplico/bin/mpaltalk
%attr(755, apache, apache)	/opt/xplico/bin/wbm_gmail.py
%attr(755, apache, apache)	/opt/xplico/bin/wbm_yahoo.py
%attr(755, apache, apache)	/opt/xplico/bin/wbm_live.pyc
%attr(755, apache, apache)	/opt/xplico/bin/wbm_yahoo.pyc
%attr(755, apache, apache)	/opt/xplico/bin/wbm_libero.py
%attr(755, apache, apache)	/opt/xplico/bin/mfbc
%attr(755, apache, apache)	/opt/xplico/bin/trigcap
%attr(755, apache, apache)	/opt/xplico/bin/wbm_aol.pyc
%attr(755, apache, apache)	/opt/xplico/bin/wbm_gmail.pyc
%dir				/opt/xplico/bin/modules
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_udp_ca.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_mpls.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_imap.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_ipsec.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_eth.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/disp_cli_list.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/cap_pcap.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_ipv6.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/cap_ca.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_sll.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_ipsec_ca.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_tcp_grb.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_tcp_nocheck.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_mgcp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_telnet.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_ip.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_ppp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_nntp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_radiotap.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/disp_capostgres.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_chdlc.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_udp_grb.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_ftp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/disp_ximysql.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_pjl.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_ppi.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_mms.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_syslog.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_webymsg.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_icmpv6_nocheck.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_rtp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_null.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_tcp_soft_nocheck.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_tcp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_paltalk_exp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_icmp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_pcapf.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_msn.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_l2tp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_dns_ca.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/disp_pcap2wav.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_ieee80211.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_udp_nocheck.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/disp_cli.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_icmpv6.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_tcp_soft.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/disp_ximysql_list.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_gtp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/cap_rltm_pol.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_tftp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_udp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_ip_nocheck.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/cap_pol.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_prism.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_sdp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_httpfd.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/cap_rltm.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_webmail.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_pop.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_arp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/disp_none.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_dns.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_pol.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_vlan.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_ipp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_paltalk.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_wa.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_fbwchat.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_http.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_irc.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_rtcp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_pppoe.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_sip.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_llc.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/disp_lite.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/disp_lite_list.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_gre.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_smtp.so
%attr(755, apache, apache)	/opt/xplico/bin/modules/dis_tcp_ca.so
%attr(755, apache, apache)	/opt/xplico/bin/wbm_yahoo_v2.pyc
%attr(755, apache, apache)	/opt/xplico/bin/wbm_yahoo_v2.py
%attr(755, apache, apache)	/opt/xplico/bin/wbm_rediff.py
%attr(755, apache, apache)	/opt/xplico/bin/mwmail
%attr(755, apache, apache)	/opt/xplico/bin/wbm_libero.pyc
%attr(755, apache, apache)	/opt/xplico/bin/wbm_yahoo_android.pyc
%attr(755, apache, apache)	/opt/xplico/bin/wbm_live.py
%attr(755, apache, apache)	/opt/xplico/bin/wbm_yahoo_android.py
%attr(755, apache, apache)	/opt/xplico/bin/mwebymsg
%attr(755, apache, apache)	/opt/xplico/bin/wbm_aol_v2.pyc
%attr(755, apache, apache)	/opt/xplico/bin/msite
%attr(755, apache, apache)	/opt/xplico/bin/wbm_rossoalice.pyc
%attr(755, apache, apache)	/opt/xplico/bin/dema
%attr(755, apache, apache)	/opt/xplico/bin/wbm_aol_v2.py
%attr(755, apache, apache)	/opt/xplico/bin/wbm_aol.py
%attr(755, apache, apache)	/opt/xplico/bin/wbm_rossoalice.py
%attr(755, apache, apache)	/opt/xplico/bin/xplico
%attr(644, apache, apache)	/opt/xplico/GeoLiteCity.dat
%attr(644, apache, apache)	/opt/xplico/COPYING.CC_BY-NC-SA
%dir				/opt/xplico/xi
%dir				/opt/xplico/xi/vendors
%attr(644, apache, apache)	/opt/xplico/xi/vendors/empty
%dir				/opt/xplico/xi/plugins
%attr(644, apache, apache)	/opt/xplico/xi/plugins/empty
%attr(644, apache, apache)	/opt/xplico/xi/index.php
%dir				/opt/xplico/xi/lib
%dir				/opt/xplico/xi/lib/Cake
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/bootstrap.php
%dir				/opt/xplico/xi/lib/Cake/View
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/XmlView.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/JsonView.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/ThemeView.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/MediaView.php
%dir				/opt/xplico/xi/lib/Cake/View/Helper
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Helper/PrototypeEngineHelper.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Helper/FlashHelper.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Helper/HtmlHelper.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Helper/MootoolsEngineHelper.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Helper/TextHelper.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Helper/TimeHelper.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Helper/CacheHelper.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Helper/JqueryEngineHelper.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Helper/SessionHelper.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Helper/JsHelper.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Helper/NumberHelper.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Helper/PaginatorHelper.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Helper/FormHelper.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Helper/JsBaseEngineHelper.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Helper/RssHelper.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/View.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/HelperCollection.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Helper.php
%dir				/opt/xplico/xi/lib/Cake/View/Scaffolds
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Scaffolds/index.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Scaffolds/form.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Scaffolds/view.ctp
%dir				/opt/xplico/xi/lib/Cake/View/Elements
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Elements/sql_dump.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Elements/exception_stack_trace.ctp
%dir				/opt/xplico/xi/lib/Cake/View/Elements/Flash
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Elements/Flash/success.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Elements/Flash/error.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Elements/Flash/default.ctp
%dir				/opt/xplico/xi/lib/Cake/View/Errors
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Errors/missing_layout.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Errors/missing_database.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Errors/missing_component.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Errors/missing_helper.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Errors/missing_connection.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Errors/missing_controller.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Errors/scaffold_error.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Errors/missing_datasource.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Errors/missing_plugin.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Errors/missing_action.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Errors/private_action.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Errors/missing_behavior.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Errors/missing_table.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Errors/missing_view.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Errors/missing_datasource_config.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Errors/fatal_error.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/Errors/pdo_error.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/ViewBlock.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/View/ScaffoldView.php
%dir				/opt/xplico/xi/lib/Cake/Core
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Core/Object.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Core/App.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Core/Configure.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Core/CakePlugin.php
%dir				/opt/xplico/xi/lib/Cake/I18n
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/I18n/Multibyte.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/I18n/I18n.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/I18n/L10n.php
%dir				/opt/xplico/xi/lib/Cake/Log
%dir				/opt/xplico/xi/lib/Cake/Log/Engine
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Log/Engine/BaseLog.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Log/Engine/ConsoleLog.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Log/Engine/FileLog.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Log/Engine/SyslogLog.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Log/CakeLog.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Log/CakeLogInterface.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Log/LogEngineCollection.php
%dir				/opt/xplico/xi/lib/Cake/Config
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Config/routes.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Config/cacert.pem
%dir				/opt/xplico/xi/lib/Cake/Config/unicode
%dir				/opt/xplico/xi/lib/Cake/Config/unicode/casefolding
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Config/unicode/casefolding/0530_058f.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Config/unicode/casefolding/2c00_2c5f.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Config/unicode/casefolding/2100_214f.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Config/unicode/casefolding/1f00_1fff.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Config/unicode/casefolding/2460_24ff.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Config/unicode/casefolding/2c80_2cff.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Config/unicode/casefolding/0370_03ff.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Config/unicode/casefolding/0500_052f.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Config/unicode/casefolding/2c60_2c7f.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Config/unicode/casefolding/2150_218f.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Config/unicode/casefolding/0400_04ff.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Config/unicode/casefolding/ff00_ffef.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Config/unicode/casefolding/0250_02af.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Config/unicode/casefolding/0180_024F.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Config/unicode/casefolding/0100_017f.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Config/unicode/casefolding/0080_00ff.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Config/unicode/casefolding/1e00_1eff.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Config/config.php
%dir				/opt/xplico/xi/lib/Cake/Console
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Shell.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/ConsoleOutput.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/cake.bat
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/ShellDispatcher.php
%dir				/opt/xplico/xi/lib/Cake/Console/Helper
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Helper/TableShellHelper.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Helper/BaseShellHelper.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Helper/ProgressShellHelper.php
%attr(755, apache, apache)	/opt/xplico/xi/lib/Cake/Console/cake
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/TaskCollection.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/ConsoleErrorHandler.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/HelpFormatter.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/ConsoleInputArgument.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/ConsoleInputOption.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/ConsoleInput.php
%dir				/opt/xplico/xi/lib/Cake/Console/Command
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Command/BakeShell.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Command/UpgradeShell.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Command/ConsoleShell.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Command/I18nShell.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Command/TestShell.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Command/ApiShell.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Command/CommandListShell.php
%dir				/opt/xplico/xi/lib/Cake/Console/Command/Task
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Command/Task/TemplateTask.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Command/Task/ExtractTask.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Command/Task/PluginTask.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Command/Task/DbConfigTask.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Command/Task/ModelTask.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Command/Task/ProjectTask.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Command/Task/ControllerTask.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Command/Task/TestTask.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Command/Task/BakeTask.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Command/Task/FixtureTask.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Command/Task/CommandTask.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Command/Task/ViewTask.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Command/CompletionShell.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Command/AppShell.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Command/AclShell.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Command/SchemaShell.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Command/TestsuiteShell.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Command/ServerShell.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/ConsoleOptionParser.php
%dir				/opt/xplico/xi/lib/Cake/Console/Templates
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/Test
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/Test/Case
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Test/Case/AllTestsTest.php
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/Test/Case/View
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/Test/Case/View/Helper
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Test/Case/View/Helper/empty
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/Test/Case/Controller
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/Test/Case/Controller/Component
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Test/Case/Controller/Component/empty
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/Test/Case/Model
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/Test/Case/Model/Behavior
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Test/Case/Model/Behavior/empty
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/Test/Fixture
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Test/Fixture/empty
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/View
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Pages
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Pages/home.ctp
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Helper
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Helper/AppHelper.php
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Layouts
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Layouts/ajax.ctp
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Layouts/rss
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Layouts/rss/default.ctp
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Layouts/js
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Layouts/js/default.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Layouts/error.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Layouts/default.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Layouts/flash.ctp
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Layouts/Emails
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Layouts/Emails/html
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Layouts/Emails/html/default.ctp
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Layouts/Emails/text
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Layouts/Emails/text/default.ctp
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Layouts/xml
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Layouts/xml/default.ctp
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Scaffolds
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Scaffolds/empty
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Elements
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Elements/Flash
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Elements/Flash/default.ctp
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Errors
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Errors/error400.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Errors/error500.ctp
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Emails
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Emails/html
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Emails/html/default.ctp
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Emails/text
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/View/Emails/text/default.ctp
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/tmp
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/tmp/logs
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/tmp/logs/empty
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/tmp/sessions
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/tmp/sessions/empty
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/tmp/cache
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/tmp/cache/persistent
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/tmp/cache/persistent/empty
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/tmp/cache/models
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/tmp/cache/models/empty
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/tmp/cache/views
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/tmp/cache/views/empty
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/tmp/tests
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/tmp/tests/empty
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/webroot
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/webroot/favicon.ico
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/webroot/files
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/webroot/files/empty
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/webroot/index.php
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/webroot/js
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/webroot/js/empty
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/webroot/css
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/webroot/css/cake.generic.css
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/webroot/test.php
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/webroot/img
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/webroot/img/test-fail-icon.png
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/webroot/img/cake.icon.png
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/webroot/img/test-skip-icon.png
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/webroot/img/test-pass-icon.png
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/webroot/img/cake.power.gif
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/webroot/img/test-error-icon.png
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/webroot/.htaccess
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/Config
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Config/bootstrap.php
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/Config/Schema
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Config/Schema/sessions.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Config/Schema/i18n.sql
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Config/Schema/db_acl.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Config/Schema/i18n.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Config/Schema/sessions.sql
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Config/Schema/db_acl.sql
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Config/acl.ini.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Config/core.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Config/database.php.default
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Config/routes.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Config/email.php.default
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Config/acl.php
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/Console
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Console/cake.bat
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Console/cake
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/Console/Command
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/Console/Command/Task
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Console/Command/Task/empty
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Console/Command/AppShell.php
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/Console/Templates
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Console/Templates/empty
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Console/cake.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/index.php
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/Controller
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/Controller/Component
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Controller/Component/empty
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Controller/AppController.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Controller/PagesController.php
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/Plugin
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Plugin/empty
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/Vendor
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Vendor/empty
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/Locale
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/Locale/eng
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/Locale/eng/LC_MESSAGES
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Locale/eng/LC_MESSAGES/empty
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/Model
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/Model/Datasource
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Model/Datasource/empty
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Model/AppModel.php
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/Model/Behavior
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Model/Behavior/empty
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/skel/Lib
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/Lib/empty
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/skel/.htaccess
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/default
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/default/classes
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/default/classes/fixture.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/default/classes/controller.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/default/classes/test.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/default/classes/model.ctp
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/default/actions
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/default/actions/controller_actions.ctp
%dir				/opt/xplico/xi/lib/Cake/Console/Templates/default/views
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/default/views/index.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/default/views/form.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/Templates/default/views/view.ctp
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/ConsoleInputSubcommand.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Console/cake.php
%dir				/opt/xplico/xi/lib/Cake/Event
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Event/CakeEventListener.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Event/CakeEvent.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Event/CakeEventManager.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/basics.php
%dir				/opt/xplico/xi/lib/Cake/Controller
%dir				/opt/xplico/xi/lib/Cake/Controller/Component
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/Component/FlashComponent.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/Component/AclComponent.php
%dir				/opt/xplico/xi/lib/Cake/Controller/Component/Acl
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/Component/Acl/DbAcl.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/Component/Acl/IniAcl.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/Component/Acl/PhpAcl.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/Component/Acl/AclInterface.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/Component/RequestHandlerComponent.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/Component/AuthComponent.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/Component/CookieComponent.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/Component/SessionComponent.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/Component/PaginatorComponent.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/Component/SecurityComponent.php
%dir				/opt/xplico/xi/lib/Cake/Controller/Component/Auth
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/Component/Auth/BasicAuthenticate.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/Component/Auth/BlowfishAuthenticate.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/Component/Auth/ControllerAuthorize.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/Component/Auth/BaseAuthenticate.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/Component/Auth/FormAuthenticate.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/Component/Auth/CrudAuthorize.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/Component/Auth/SimplePasswordHasher.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/Component/Auth/BlowfishPasswordHasher.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/Component/Auth/DigestAuthenticate.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/Component/Auth/ActionsAuthorize.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/Component/Auth/AbstractPasswordHasher.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/Component/Auth/BaseAuthorize.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/Component/EmailComponent.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/Scaffold.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/Component.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/ComponentCollection.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/CakeErrorController.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Controller/Controller.php
%dir				/opt/xplico/xi/lib/Cake/Utility
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Utility/File.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Utility/Inflector.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Utility/Folder.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Utility/Hash.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Utility/CakeTime.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Utility/Set.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Utility/Sanitize.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Utility/CakeText.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Utility/Validation.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Utility/Debugger.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Utility/String.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Utility/ObjectCollection.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Utility/Xml.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Utility/CakeNumber.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Utility/Security.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Utility/ClassRegistry.php
%dir				/opt/xplico/xi/lib/Cake/Network
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Network/CakeSocket.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Network/CakeResponse.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Network/CakeRequest.php
%dir				/opt/xplico/xi/lib/Cake/Network/Email
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Network/Email/DebugTransport.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Network/Email/AbstractTransport.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Network/Email/MailTransport.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Network/Email/SmtpTransport.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Network/Email/CakeEmail.php
%dir				/opt/xplico/xi/lib/Cake/Network/Http
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Network/Http/HttpResponse.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Network/Http/DigestAuthentication.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Network/Http/HttpSocket.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Network/Http/BasicAuthentication.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Network/Http/HttpSocketResponse.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/VERSION.txt
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/LICENSE.txt
%dir				/opt/xplico/xi/lib/Cake/Routing
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Routing/Dispatcher.php
%dir				/opt/xplico/xi/lib/Cake/Routing/Route
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Routing/Route/RedirectRoute.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Routing/Route/CakeRoute.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Routing/Route/PluginShortRoute.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Routing/DispatcherFilter.php
%dir				/opt/xplico/xi/lib/Cake/Routing/Filter
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Routing/Filter/AssetDispatcher.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Routing/Filter/CacheDispatcher.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Routing/Router.php
%dir				/opt/xplico/xi/lib/Cake/Model
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Model/ConnectionManager.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Model/ModelValidator.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Model/CakeSchema.php
%dir				/opt/xplico/xi/lib/Cake/Model/Datasource
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Model/Datasource/CakeSession.php
%dir				/opt/xplico/xi/lib/Cake/Model/Datasource/Database
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Model/Datasource/Database/Postgres.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Model/Datasource/Database/Mysql.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Model/Datasource/Database/Sqlite.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Model/Datasource/Database/Sqlserver.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Model/Datasource/DboSource.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Model/Datasource/DataSource.php
%dir				/opt/xplico/xi/lib/Cake/Model/Datasource/Session
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Model/Datasource/Session/CakeSessionHandlerInterface.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Model/Datasource/Session/CacheSession.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Model/Datasource/Session/DatabaseSession.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Model/Permission.php
%dir				/opt/xplico/xi/lib/Cake/Model/Validator
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Model/Validator/CakeValidationSet.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Model/Validator/CakeValidationRule.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Model/Aro.php
%dir				/opt/xplico/xi/lib/Cake/Model/Behavior
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Model/Behavior/ContainableBehavior.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Model/Behavior/AclBehavior.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Model/Behavior/TreeBehavior.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Model/Behavior/TranslateBehavior.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Model/Aco.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Model/BehaviorCollection.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Model/ModelBehavior.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Model/I18nModel.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Model/Model.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Model/AcoAction.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Model/AclNode.php
%dir				/opt/xplico/xi/lib/Cake/TestSuite
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/TestSuite/CakeTestSuiteDispatcher.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/TestSuite/CakeTestSuiteCommand.php
%dir				/opt/xplico/xi/lib/Cake/TestSuite/Stub
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/TestSuite/Stub/ConsoleOutputStub.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/TestSuite/CakeTestCase.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/TestSuite/CakeTestLoader.php
%dir				/opt/xplico/xi/lib/Cake/TestSuite/Coverage
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/TestSuite/Coverage/BaseCoverageReport.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/TestSuite/Coverage/TextCoverageReport.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/TestSuite/Coverage/HtmlCoverageReport.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/TestSuite/CakeTestSuite.php
%dir				/opt/xplico/xi/lib/Cake/TestSuite/templates
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/TestSuite/templates/xdebug.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/TestSuite/templates/menu.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/TestSuite/templates/missing_connection.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/TestSuite/templates/header.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/TestSuite/templates/phpunit.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/TestSuite/templates/footer.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/TestSuite/ControllerTestCase.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/TestSuite/CakeTestRunner.php
%dir				/opt/xplico/xi/lib/Cake/TestSuite/Reporter
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/TestSuite/Reporter/CakeBaseReporter.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/TestSuite/Reporter/CakeTextReporter.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/TestSuite/Reporter/CakeHtmlReporter.php
%dir				/opt/xplico/xi/lib/Cake/TestSuite/Fixture
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/TestSuite/Fixture/CakeTestFixture.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/TestSuite/Fixture/CakeFixtureManager.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/TestSuite/Fixture/CakeTestModel.php
%dir				/opt/xplico/xi/lib/Cake/Configure
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Configure/IniReader.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Configure/PhpReader.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Configure/ConfigReaderInterface.php
%dir				/opt/xplico/xi/lib/Cake/Cache
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Cache/CacheEngine.php
%dir				/opt/xplico/xi/lib/Cake/Cache/Engine
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Cache/Engine/ApcEngine.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Cache/Engine/RedisEngine.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Cache/Engine/WincacheEngine.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Cache/Engine/MemcachedEngine.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Cache/Engine/FileEngine.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Cache/Engine/XcacheEngine.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Cache/Engine/MemcacheEngine.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Cache/Cache.php
%dir				/opt/xplico/xi/lib/Cake/Error
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Error/exceptions.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Error/ExceptionRenderer.php
%attr(644, apache, apache)	/opt/xplico/xi/lib/Cake/Error/ErrorHandler.php
%dir				/opt/xplico/xi/app
%dir				/opt/xplico/xi/app/View
%dir				/opt/xplico/xi/app/View/Ircs
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Ircs/index.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Ircs/channel.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Ircs/view.ctp
%dir				/opt/xplico/xi/app/View/PaltalkRooms
%attr(644, apache, apache)	/opt/xplico/xi/app/View/PaltalkRooms/index.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/PaltalkRooms/room.ctp
%dir				/opt/xplico/xi/app/View/Mgcps
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Mgcps/caller_play.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Mgcps/called_play.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Mgcps/index.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Mgcps/view.ctp
%dir				/opt/xplico/xi/app/View/Icmpv6s
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Icmpv6s/index.ctp
%dir				/opt/xplico/xi/app/View/NntpGroups
%attr(644, apache, apache)	/opt/xplico/xi/app/View/NntpGroups/index.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/NntpGroups/alist.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/NntpGroups/view.ctp
%dir				/opt/xplico/xi/app/View/Sols
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Sols/add.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Sols/index.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Sols/view.ctp
%dir				/opt/xplico/xi/app/View/Ftps
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Ftps/index.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Ftps/view.ctp
%dir				/opt/xplico/xi/app/View/Mms
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Mms/index.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Mms/view.ctp
%dir				/opt/xplico/xi/app/View/Tftps
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Tftps/index.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Tftps/view.ctp
%dir				/opt/xplico/xi/app/View/DnsMessages
%attr(644, apache, apache)	/opt/xplico/xi/app/View/DnsMessages/index.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/DnsMessages/graph.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/DnsMessages/site_graph.ctp
%dir				/opt/xplico/xi/app/View/Telnets
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Telnets/index.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Telnets/view.ctp
%dir				/opt/xplico/xi/app/View/MsnChats
%attr(644, apache, apache)	/opt/xplico/xi/app/View/MsnChats/chat.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/MsnChats/index.ctp
%dir				/opt/xplico/xi/app/View/Rtps
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Rtps/caller_play.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Rtps/called_play.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Rtps/index.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Rtps/view.ctp
%dir				/opt/xplico/xi/app/View/Pols
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Pols/add.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Pols/index.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Pols/view.ctp
%dir				/opt/xplico/xi/app/View/Fbuchats
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Fbuchats/index.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Fbuchats/chats.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Fbuchats/view.ctp
%dir				/opt/xplico/xi/app/View/Arps
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Arps/index.ctp
%dir				/opt/xplico/xi/app/View/Webymsgs
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Webymsgs/index.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Webymsgs/view.ctp
%dir				/opt/xplico/xi/app/View/PaltalkExps
%attr(644, apache, apache)	/opt/xplico/xi/app/View/PaltalkExps/chat.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/PaltalkExps/index.ctp
%dir				/opt/xplico/xi/app/View/Helper
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Helper/AppHelper.php
%dir				/opt/xplico/xi/app/View/Webmails
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Webmails/index.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Webmails/view.ctp
%dir				/opt/xplico/xi/app/View/Unknows
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Unknows/index.ctp
%dir				/opt/xplico/xi/app/View/Whatsapps
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Whatsapps/index.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Whatsapps/view.ctp
%dir				/opt/xplico/xi/app/View/Configurations
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Configurations/index.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Configurations/dissectors.ctp
%dir				/opt/xplico/xi/app/View/Syslogs
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Syslogs/index.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Syslogs/view.ctp
%dir				/opt/xplico/xi/app/View/Feeds
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Feeds/xml.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Feeds/index.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Feeds/view.ctp
%dir				/opt/xplico/xi/app/View/Sips
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Sips/caller_play.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Sips/called_play.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Sips/index.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Sips/view.ctp
%dir				/opt/xplico/xi/app/View/Admins
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Admins/gadd.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Admins/groups.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Admins/uadd.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Admins/users.ctp
%dir				/opt/xplico/xi/app/View/Unkfiles
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Unkfiles/index.ctp
%dir				/opt/xplico/xi/app/View/Pjls
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Pjls/index.ctp
%dir				/opt/xplico/xi/app/View/Users
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Users/register.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Users/help.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Users/licenses.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Users/login.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Users/resend_reg.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Users/about.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Users/cpassword.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Users/register_confirm.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Users/gpl.ctp
%dir				/opt/xplico/xi/app/View/Inputs
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Inputs/geomap.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Inputs/index.ctp
%dir				/opt/xplico/xi/app/View/Webs
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Webs/hijacking.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Webs/images.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Webs/index.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Webs/method.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Webs/play.ctp
%dir				/opt/xplico/xi/app/View/Layouts
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Layouts/ajax.ctp
%dir				/opt/xplico/xi/app/View/Layouts/rss
%attr(755, apache, apache)	/opt/xplico/xi/app/View/Layouts/rss/empty
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Layouts/rss/default.ctp
%dir				/opt/xplico/xi/app/View/Layouts/js
%attr(755, apache, apache)	/opt/xplico/xi/app/View/Layouts/js/empty
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Layouts/js/default.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Layouts/error.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Layouts/default.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Layouts/licenses.ctp
%dir				/opt/xplico/xi/app/View/Layouts/email
%dir				/opt/xplico/xi/app/View/Layouts/email/html
%attr(755, apache, apache)	/opt/xplico/xi/app/View/Layouts/email/html/empty
%dir				/opt/xplico/xi/app/View/Layouts/email/text
%attr(755, apache, apache)	/opt/xplico/xi/app/View/Layouts/email/text/empty
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Layouts/flash.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Layouts/voip.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Layouts/cookies.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Layouts/rdf.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Layouts/fbchat.ctp
%dir				/opt/xplico/xi/app/View/Layouts/Emails
%dir				/opt/xplico/xi/app/View/Layouts/Emails/html
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Layouts/Emails/html/default.ctp
%dir				/opt/xplico/xi/app/View/Layouts/Emails/text
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Layouts/Emails/text/default.ctp
%dir				/opt/xplico/xi/app/View/Layouts/xml
%attr(755, apache, apache)	/opt/xplico/xi/app/View/Layouts/xml/empty
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Layouts/xml/default.ctp
%dir				/opt/xplico/xi/app/View/Httpfiles
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Httpfiles/index.ctp
%dir				/opt/xplico/xi/app/View/Scaffolds
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Scaffolds/empty
%dir				/opt/xplico/xi/app/View/Elements
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Elements/empty
%dir				/opt/xplico/xi/app/View/Elements/email
%dir				/opt/xplico/xi/app/View/Elements/email/html
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Elements/email/html/empty
%dir				/opt/xplico/xi/app/View/Elements/email/text
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Elements/email/text/empty
%dir				/opt/xplico/xi/app/View/Errors
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Errors/error400.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Errors/empty
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Errors/error500.ctp
%dir				/opt/xplico/xi/app/View/Emails
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Emails/index.ctp
%attr(644, apache, apache)	/opt/xplico/xi/app/View/Emails/view.ctp
%dir				/opt/xplico/xi/app/tmp
%dir				/opt/xplico/xi/app/tmp/logs
%attr(777, apache, apache)	/opt/xplico/xi/app/tmp/logs/empty
%dir				/opt/xplico/xi/app/tmp/sessions
%attr(777, apache, apache)	/opt/xplico/xi/app/tmp/sessions/empty
%dir				/opt/xplico/xi/app/tmp/cache
%dir				/opt/xplico/xi/app/tmp/cache/persistent
%attr(777, apache, apache)	/opt/xplico/xi/app/tmp/cache/persistent/empty
%dir				/opt/xplico/xi/app/tmp/cache/models
%attr(777, apache, apache)	/opt/xplico/xi/app/tmp/cache/models/empty
%dir				/opt/xplico/xi/app/tmp/cache/views
%attr(777, apache, apache)	/opt/xplico/xi/app/tmp/cache/views/empty
%dir				/opt/xplico/xi/app/tmp/tests
%attr(777, apache, apache)	/opt/xplico/xi/app/tmp/tests/empty
%dir				/opt/xplico/xi/app/webroot
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/favicon.ico
%dir				/opt/xplico/xi/app/webroot/files
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/files/flowplayer-3.2.2.swf
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/files/open-flash-chart.swf
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/files/flowplayer.controls-3.2.1.swf
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/files/xplico_voip_mix.swf
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/files/xplico_voip.swf
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/index.php
%dir				/opt/xplico/xi/app/webroot/js
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/js/vendors.php
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/js/jquery.js
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/js/check_ver.js
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/js/swfobject.js
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/js/jquery-ui-custom.min.js
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/js/http_get.js
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/js/jquery.tools.min.js
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/js/flowplayer-3.2.2.min.js
%dir				/opt/xplico/xi/app/webroot/css
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/html.css
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/webimages.css
%dir				/opt/xplico/xi/app/webroot/css/themes
%dir				/opt/xplico/xi/app/webroot/css/themes/ui-darkness
%dir				/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-bg_glass_20_555555_1x400.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-bg_glass_40_0078a3_1x400.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-bg_gloss-wave_25_333333_500x100.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-icons_cccccc_256x240.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-icons_4b8e0b_256x240.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-icons_ffffff_256x240.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-bg_flat_50_5c5c5c_40x100.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-bg_flat_30_cccccc_40x100.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-bg_inset-soft_30_f58400_1x100.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/pbar-ani.gif
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-icons_a83300_256x240.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-bg_highlight-soft_80_eeeeee_1x100.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-icons_222222_256x240.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-bg_inset-soft_25_000000_1x100.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-bg_glass_40_ffc73d_1x400.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/jquery-ui-custom.css
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/cake.generic.css
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/flows.css
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/facebookchat.css
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/mail.css
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/css/style.css
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/relevance.html
%dir				/opt/xplico/xi/app/webroot/img
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/delete_64.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/pcapsize.gif
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/loading.gif
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/button-iserm.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/over_close.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/cake.icon.gif
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/devel_empty.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/capanalysis.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/slider.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/statistics.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/database.gif
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/update.gif
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/over_white.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/deft.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/version.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/cake.power.gif
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/tick_64.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/deft_link.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/enable.gif
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/disable.gif
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/button-xplico.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/dot.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/cake.power.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/menu-bits.gif
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/w3c_xhtml10.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/geoposition.gif
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/devel.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/img/w3c_css.png
%attr(644, apache, apache)	/opt/xplico/xi/app/webroot/.htaccess
%dir				/opt/xplico/xi/app/Config
%attr(644, apache, apache)	/opt/xplico/xi/app/Config/bootstrap.php
%dir				/opt/xplico/xi/app/Config/Schema
%attr(644, apache, apache)	/opt/xplico/xi/app/Config/Schema/sessions.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Config/Schema/i18n.sql
%attr(644, apache, apache)	/opt/xplico/xi/app/Config/Schema/db_acl.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Config/Schema/i18n.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Config/Schema/sessions.sql
%attr(644, apache, apache)	/opt/xplico/xi/app/Config/Schema/db_acl.sql
%attr(644, apache, apache)	/opt/xplico/xi/app/Config/acl.ini.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Config/core.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Config/database.php.default
%attr(644, apache, apache)	/opt/xplico/xi/app/Config/routes.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Config/database.php_postgresql
%attr(644, apache, apache)	/opt/xplico/xi/app/Config/email.php.default
%attr(644, apache, apache)	/opt/xplico/xi/app/Config/acl.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Config/database.php.sqlite3
%attr(644, apache, apache)	/opt/xplico/xi/app/Config/database.php
%dir				/opt/xplico/xi/app/Console
%attr(644, apache, apache)	/opt/xplico/xi/app/Console/cake.bat
%attr(755, apache, apache)	/opt/xplico/xi/app/Console/cake
%dir				/opt/xplico/xi/app/Console/Command
%dir				/opt/xplico/xi/app/Console/Command/Task
%attr(644, apache, apache)	/opt/xplico/xi/app/Console/Command/Task/empty
%attr(644, apache, apache)	/opt/xplico/xi/app/Console/Command/AppShell.php
%dir				/opt/xplico/xi/app/Console/Templates
%attr(644, apache, apache)	/opt/xplico/xi/app/Console/Templates/empty
%attr(644, apache, apache)	/opt/xplico/xi/app/Console/cake.php
%attr(644, apache, apache)	/opt/xplico/xi/app/index.php
%dir				/opt/xplico/xi/app/Controller
%dir				/opt/xplico/xi/app/Controller/Component
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/Component/SearchPathComponent.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/Component/XplicoComponent.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/Component/Xml2PcapComponent.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/MmsController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/FbuchatsController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/ArpsController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/DnsMessagesController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/AdminsController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/InputsController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/UnknowsController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/SipsController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/FeedsController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/commonlib.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/TftpsController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/TelnetsController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/WhatsappsController.php
%dir				/opt/xplico/xi/app/Controller/php-ofc-library
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/json_format.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_tooltip.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_y_axis_label.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_bar_filled.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_scatter.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/dot_base.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_area_line.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_title.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_y_axis.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/README.txt
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_x_legend.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_area_base.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_line.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_upload_image.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_x_axis_labels.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_tags.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_hbar.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_bar_base.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/open-flash-chart.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_bar_glass.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_x_axis_label.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_line_base.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_y_legend.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_line_style.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_bar_3d.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_line_dot.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_bar.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_bar_stack.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_candle.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_radar_spoke_labels.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/open-flash-chart-object.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/JSON.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_area_hollow.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_y_axis_labels.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_bar_sketch.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_y_axis_base.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_y_axis_right.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_radar_axis_labels.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_x_axis.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_scatter_line.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_menu.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_radar_axis.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_shape.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_line_hollow.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_pie.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_arrow.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/php-ofc-library/ofc_sugar.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/UsersController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/mime_parser.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/HttpfilesController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/RtpsController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/IrcsController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/EmailsController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/AppController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/WebymsgsController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/WebsController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/PjlsController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/SolsController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/Icmpv6sController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/PaltalkRoomsController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/rfc822_addresses.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/FtpsController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/PolsController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/UnkfilesController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/ConfigurationsController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/MgcpsController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/SyslogsController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/NntpGroupsController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/WebmailsController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/MsnChatsController.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Controller/PaltalkExpsController.php
%dir				/opt/xplico/xi/app/Plugin
%attr(644, apache, apache)	/opt/xplico/xi/app/Plugin/empty
%dir				/opt/xplico/xi/app/Vendor
%attr(644, apache, apache)	/opt/xplico/xi/app/Vendor/empty
%dir				/opt/xplico/xi/app/Locale
%attr(644, apache, apache)	/opt/xplico/xi/app/Locale/default.pot
%dir				/opt/xplico/xi/app/Locale/fre
%dir				/opt/xplico/xi/app/Locale/fre/LC_MESSAGES
%attr(644, apache, apache)	/opt/xplico/xi/app/Locale/fre/LC_MESSAGES/default.po
%dir				/opt/xplico/xi/app/Locale/spa
%dir				/opt/xplico/xi/app/Locale/spa/LC_MESSAGES
%attr(644, apache, apache)	/opt/xplico/xi/app/Locale/spa/LC_MESSAGES/default.po
%dir				/opt/xplico/xi/app/Locale/ita
%dir				/opt/xplico/xi/app/Locale/ita/LC_MESSAGES
%attr(644, apache, apache)	/opt/xplico/xi/app/Locale/ita/LC_MESSAGES/default.po
%dir				/opt/xplico/xi/app/Locale/zh_tw
%dir				/opt/xplico/xi/app/Locale/zh_tw/LC_MESSAGES
%attr(644, apache, apache)	/opt/xplico/xi/app/Locale/zh_tw/LC_MESSAGES/default.po
%dir				/opt/xplico/xi/app/Locale/eng
%dir				/opt/xplico/xi/app/Locale/eng/LC_MESSAGES
%attr(644, apache, apache)	/opt/xplico/xi/app/Locale/eng/LC_MESSAGES/default.po
%dir				/opt/xplico/xi/app/Locale/tur
%dir				/opt/xplico/xi/app/Locale/tur/LC_MESSAGES
%attr(644, apache, apache)	/opt/xplico/xi/app/Locale/tur/LC_MESSAGES/default.po
%dir				/opt/xplico/xi/app/Locale/deu
%dir				/opt/xplico/xi/app/Locale/deu/LC_MESSAGES
%attr(644, apache, apache)	/opt/xplico/xi/app/Locale/deu/LC_MESSAGES/default.po
%dir				/opt/xplico/xi/app/Locale/hin
%dir				/opt/xplico/xi/app/Locale/hin/LC_MESSAGES
%attr(644, apache, apache)	/opt/xplico/xi/app/Locale/hin/LC_MESSAGES/default.po
%dir				/opt/xplico/xi/app/Locale/pt_br
%dir				/opt/xplico/xi/app/Locale/pt_br/LC_MESSAGES
%attr(644, apache, apache)	/opt/xplico/xi/app/Locale/pt_br/LC_MESSAGES/default.po
%dir				/opt/xplico/xi/app/Locale/zh_cn
%dir				/opt/xplico/xi/app/Locale/zh_cn/LC_MESSAGES
%attr(644, apache, apache)	/opt/xplico/xi/app/Locale/zh_cn/LC_MESSAGES/default.po
%dir				/opt/xplico/xi/app/Locale/ara
%dir				/opt/xplico/xi/app/Locale/ara/LC_MESSAGES
%attr(644, apache, apache)	/opt/xplico/xi/app/Locale/ara/LC_MESSAGES/default.po
%dir				/opt/xplico/xi/app/Locale/jpn
%dir				/opt/xplico/xi/app/Locale/jpn/LC_MESSAGES
%attr(644, apache, apache)	/opt/xplico/xi/app/Locale/jpn/LC_MESSAGES/default.po
%dir				/opt/xplico/xi/app/Locale/rus
%dir				/opt/xplico/xi/app/Locale/rus/LC_MESSAGES
%attr(644, apache, apache)	/opt/xplico/xi/app/Locale/rus/LC_MESSAGES/default.po_orig
%attr(644, apache, apache)	/opt/xplico/xi/app/Locale/rus/LC_MESSAGES/default.po
%dir				/opt/xplico/xi/app/Locale/por
%dir				/opt/xplico/xi/app/Locale/por/LC_MESSAGES
%attr(644, apache, apache)	/opt/xplico/xi/app/Locale/por/LC_MESSAGES/default.po
%dir				/opt/xplico/xi/app/Model
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Ftp_file.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Source.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Irc.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/User.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Tftp.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/DnsMessage.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Paltalk_exp.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Whatsapp.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Param.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Tftp_file.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Httpfile.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Syslog.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Telnet.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Email.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Webmail.php
%dir				/opt/xplico/xi/app/Model/Datasource
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Datasource/empty
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Msn_chat.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Fbchat.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Mgcp.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/AppModel.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Unknow.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Paltalk_room.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Nntp_group.php
%dir				/opt/xplico/xi/app/Model/Behavior
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Behavior/empty
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Rtp.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Arp.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Sip.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Feed_xml.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Feed.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Mmscontent.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Pjl.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Irc_channel.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Nntp_article.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Icmpv6.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Mm.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Group.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Unkfile.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Sol.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Input.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Ftp.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Fbuchat.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Pol.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Webymsg.php
%attr(644, apache, apache)	/opt/xplico/xi/app/Model/Web.php
%dir				/opt/xplico/xi/app/Lib
%dir				/opt/xplico/xi/app/Lib/Error
%attr(644, apache, apache)	/opt/xplico/xi/app/Lib/Error/Services_JSON_Error.php
%attr(644, apache, apache)	/opt/xplico/xi/app/.htaccess
%attr(644, apache, apache)	/opt/xplico/xi/.gitignore
%attr(644, apache, apache)	/opt/xplico/xi/.htaccess

%changelog
* Fri Aug  4 2017 Lawrence R. Rogers <lrr@cert.org> 1.2.0-3
* Release 1.2.0-3
	Recompiled for new version of nDPI (2.1)

* Wed May 24 2017 Lawrence R. Rogers <lrr@cert.org> 1.2.0-2
* Release 1.2.0-2
	New version of lame and lame-libs.

* Wed Jan 18 2017 Lawrence R. Rogers <lrr@cert.org> 1.2.0-1
* Release 1.2.0-1
	* This is the 1.2.0 version.
		xplico 1.2.0
		  * Migration from PHP5 to PHP7
		  * CakePHP 2.8
		  * IMAP bug fix
		  * Bugfix: reported on Security Onion

		xplico 1.1.2
		  * IPv4 defragmentation
		  * CapAnalysis dissectors and dispatcher

* Wed Dec  7 2016 Lawrence R. Rogers <lrr@cert.org> 1.1.1-6
* Release 1.1.1-6
	* Created pyc files for Fedora 24 from the 1.1.2 distribution.

* Mon Oct 24 2016 Lawrence R. Rogers <lrr@cert.org> 1.1.1-5
* Release 1.1.1-5
	* The PHP configuration is now also in the start and stop code.

* Fri Oct 21 2016 Lawrence R. Rogers <lrr@cert.org> 1.1.1-4
* Release 1.1.1-4
	* CentOS/RHEL 7 also uses systemctl.

* Fri Oct 21 2016 Lawrence R. Rogers <lrr@cert.org> 1.1.1-3
* Release 1.1.1-3
	* CentOS/RHEL 7 have Python 3.3.

* Sat Jul  9 2016 Lawrence R. Rogers <lrr@cert.org> 1.1.1-2
* Release 1.1.1-2
	* Recompiled for nDPI-1.8.

* Mon Nov  9 2015 Lawrence R. Rogers <lrr@cert.org> 1.1.1-1
* Release 1.1.1-1
	* Whatsapp OS and Phone number
	* Added MGCP dissector
	* IMAP bug fixed
	* Updated for nDPI-1.7.0.

* Tue Aug 18 2015 Lawrence R. Rogers <lrr@cert.org> 1.1.0-4
* Release 1.1.0-4
	Recompiled for nDPI-1.7.0.

* Mon Jun 29 2015 Lawrence R. Rogers <lrr@cert.org> 1.1.0-3
* Release 1.1.0-3
	Recompiled for nDPI-1.6.

* Wed Sep  3 2014 Lawrence R. Rogers <lrr@cert.org> 1.1.0-2
* Release 1.1.0-2
	Changes for CentOS/RHEL 7

* Mon May 12 2014 Lawrence R. Rogers <lrr@cert.org> 1.1.0-1
* Release 1.1.0-1
	xplico 1.1.0
		* Performance improved
		* nDPI updated
		* IRC bug fixed
		* HTTP bug fixed
		* VoIP (SIP, RTP) bug fixed
		* FTP bug fixed
		* changed the FaceBook DB tables
		* Null/Loopback dissector
		* Cisco HDLC dissector
		* Libero.it and RossoAlice webmail decoding
		* Yahoo messenger (web and mobile)
		* Dig using file signatures (unknown flows)

* Thu Apr 24 2014 Lawrence R. Rogers <lrr@cert.org> 1.0.1-5
* Release 1.0.1-5
	For Fedora, there is now a systemd config file and the old /etc/init.d/xplico is now in /usr/sbin.

* Tue Jan 07 2014 Lawrence R. Rogers <lrr@cert.org> 1.0.1-4
* Release 1.0.1-4
	Fix for Fedora 19 and 20 and CentOS/RHEL 6 for setsocketopt in system/dema/session_decoding.c

* Fri Aug 02 2013 Lawrence R. Rogers <lrr@cert.org> 1.0.1-3
* Release 1.0.1-3
	Patch for Fedora 19

* Tue Jul 17 2012 Lawrence Rogers <lrr@cert.org> 1.0.0-2
* Release 1.0.0-2
	For beyond Fedora 16, now starts, stops, and queries the daemon status using systemctl.
	Also, adjusts /etc/php.ini so that xplico starts and runs.

* Fri Feb 10 2012 Lawrence Rogers <lrr@cert.org> 1.0.0-1
* Release 1.0.0-1
	* SQLite dispatcher performance improved
	* added the PPI dissector
	* added the syslog dissector
	* added "Bogus IP length" correction with checksum verification disabled
	* new Facebook Chat dissector for the new Facebook chat protocol
	* SIP dissector improved
	* IMAP dissector improved and bugs fixed
	* DNS dissector PIPI improved
	* Yahoo Webmail bugs fixed
	* Live/Hotmail WebMail Spanish version
	* GeoMap improved
	* PCap-over-IP

* Sun Jan 15 2012 Lawrence Rogers <lrr@cert.org> 0.7.1-1
* Release 0.7.1-1
	* RTP bug fixed
	* dispatcher core functionality bug fixed
	* mfile manipulator bug fixed
	* XI bugs fixed
	* added DB migration tool

* Mon Nov 7 2011 Lawrence Rogers <lrr@cert.org> 0.7.0-1
* Release 0.7.0-1
	* upgraded XI to Cakephp 1.3
	* added the ICMPv6 dissector
	* Ethernet dissector improved (necessary for ICMPv6)
	* deadlock fixed
	* fixed the communication bug from xplico and manipulators
	* SDP dissector bug fixes
	* SIP and TCP dissectors improved
	* WebMail manipulator and all python3 scripts improved (ready to new webmail entry... see pol ;) )
	* added pcap file name on CLI report screen
	* capture modules log improved
	* new GeoIP version: 1.4.8
	* added IPv6 Hop-by-Hop Options
	* Xplico and all Manipulators with dual stack (IPv4, IPv6)
	* XI language localization
	* DNS bugfix
	* added the  MDNS dissector
	* added AOL WebMail
	* added Yahoo! WebMail
	* added Yahoo! Mail for Andorid Mobile
	* added Gmail

* Mon Jun 6 2011 Lawrence Rogers <lrr@cert.org> 0.6.3-1
* Release 0.6.3-1
	* xplico 32/64bit version
	* new decoding manager (DeMa) version 0.3.1
	* mfile manipulator (HTTP file transfare) bug fixes
	* WebMail scripts improved
	* HTTP dissector improved
	* upgraded the XI javascript libraries

* Tue May 3 2011 Lawrence Rogers <lrr@cert.org>  0.6.2-1
* Revision 1: Upgrade to 0.6.2 doing the following:
	l7-patterns for all flows/protocols not decoded by xplico
	Xplico Interface (XI) improved
	python3 porting of many script
	realtime capture module improved
	facebook chat realtime view
	UTC/localtime bug fixes
	l2tp dissector bug fixes
	cli and lite dispatchers bug fixes
	telnet dissector bug fixes

* Tue Mar 1 2011 Lawrence Rogers <lrr@cert.org>  0.6.1-6
* Revision 6: The /etc/init.d/xplico script no longer specific the start and stop levels.
	      These should be done identical to and after httpd, so that xplico is
		set to start after httpd.

* Fri Dec 10 2010 Lawrence Rogers <lrr@cert.org>  0.6.1-5
* Revision 5: Fixed init.d script so that it waits until httpd starts

* Thu Dec 9 2010 Lawrence Rogers <lrr@cert.org>  0.6.1-4
* Revision 4: Fixed init.d script so that it is started after httpd

* Thu Dec 9 2010 Lawrence Rogers <lrr@cert.org>  0.6.1-3
* Revision 3: Stops and restarts the server, if necessary, before adding any tables and PRAGMA values

* Thu Dec 9 2010 Lawrence Rogers <lrr@cert.org>  0.6.1-2
* Revision 2: Changed the postun script to add the msn_chats and paltalk_rooms tables to an existing database.
		Also the foreign_keys PRAGMA was turned on and the auto_vacuum value displayed.`

* Tue Dec 7 2010 Lawrence Rogers <lrr@cert.org>  0.6.1-1
* Revision 1: Version 0.6.1 from www.xplico.org

* Mon Nov 29 2010 Lawrence Rogers <lrr@cert.org> 0.6.0-10
- Revision 10: Improved (fixed?) /etc/init.d/xplico so that it waits longer for httpd to start.
  Also added httpd as a service start dependency.

* Fri Nov 19 2010 Lawrence Rogers <lrr@cert.org> 0.6.0-9
- Revision 9: 

* Thu Nov 18 2010 Lawrence Rogers <lrr@cert.org> 0.6.0-8
- Revision 8: Correctly removes pcl6 and videosnarf as pre-uninstall scripts so that the
  /opt/xplico hierarchy can be completely removed if possible when xplico is removed.

* Thu Nov 18 2010 Lawrence Rogers <lrr@cert.org> 0.6.0-7
- Revision 7: Removed pcl6 and videosnarf and made those packages prerequisites. The needed
  binaries are then copied into the /opt/xplico hierarchy using the post-install script.
  Also, the correct syntax for creating the dabase is used.

* Thu Nov 18 2010 Lawrence Rogers <lrr@cert.org> 0.6.0-6
- Revision 6: Added pcl6 and videosnarf

* Thu Nov 18 2010 Lawrence Rogers <lrr@cert.org>  0.6.0-5
- Revision 5: Fixed permissions to match those of the Debian package
  Also preserves any existing database by creating the database in the post-install script,
  as needed.

* Thu Nov 18 2010 Lawrence Rogers <lrr@cert.org> 0.6.0-4
- Revision 4: Gave execute permissions to everything in the bin directory
